/****************************************************************************
**
** Copyright (C) 2019 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <extensionsystem/iplugin.h>
#include <coreplugin/dialogs/ioptionspage.h>
#include <utils/pathchooser.h>

#include <QTimer>

QT_FORWARD_DECLARE_CLASS(QCheckBox)

namespace StudioWelcome {
namespace Internal {

class StudioSettingsPage : public Core::IOptionsPageWidget
{
    Q_OBJECT

public:
    void apply() final;

    StudioSettingsPage();

private:
    QCheckBox *m_buildCheckBox;
    QCheckBox *m_debugCheckBox;
    QCheckBox *m_analyzeCheckBox;
    Utils::PathChooser *m_pathChooser;
};

class StudioWelcomeSettingsPage : public Core::IOptionsPage
{
    Q_OBJECT

public:
    StudioWelcomeSettingsPage();
};

class StudioWelcomePlugin final : public ExtensionSystem::IPlugin
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QtCreatorPlugin" FILE "StudioWelcome.json")

public slots:
    void closeSplashScreen();
    void showSystemSettings();

public:
    StudioWelcomePlugin();
    ~StudioWelcomePlugin() final;

    bool initialize(const QStringList &arguments, QString *errorString) override;
    void extensionsInitialized() override;
    bool delayedInitialize() override;

    static Utils::FilePath defaultExamplesPath();
    static QString examplesPathSetting();

signals:
    void examplesDownloadPathChanged(const QString &path);

private:
    class WelcomeMode *m_welcomeMode = nullptr;
    StudioWelcomeSettingsPage m_settingsPage;
};

} // namespace Internal
} // namespace StudioWelcome
